@@ -1,8 +1,9 @@
 from datetime import date
 
-from cubicweb.mixins import ProgressMixIn
-from cubicweb.interfaces import IMileStone
 from cubicweb.entities import AnyEntity, fetch_config
+from cubicweb.entities.adapters import IMileStoneAdapter
+from cubicweb.web.views.ibreadcrumbs import IBreadCrumbsAdapter
+from cubicweb.selectors import is_instance
 
 class Order(AnyEntity):
     __regid__ = 'Order'
@@ -26,6 +27,7 @@ class Order(AnyEntity):
                           'done': self.progress_done,
                           'todo': self.progress_todo})
 
+    # XXX used somewhere? If so must be in an adapter
     def progress_info(self):
         return {'estimated': self.progress_target,
                 'estimatedcorrected': self.progress_target,
@@ -33,9 +35,8 @@ class Order(AnyEntity):
                 'todo': self.progress_todo,
                 }
 
-class WorkOrder(ProgressMixIn, AnyEntity):
+class WorkOrder(AnyEntity):
     __regid__ = 'WorkOrder'
-    __implements__ = AnyEntity.__implements__ + (IMileStone,)
 
     fetch_attrs, fetch_order = fetch_config(('title', 'description_format',
                                              'description', 'budget',
@@ -51,35 +52,6 @@ class WorkOrder(ProgressMixIn, AnyEntity):
     def order(self):
         return self.reverse_split_into[0]
 
-    def parent(self):
-        return self.order
-
-    ## IProgress interface ####################################################
-    parent_type = 'Order'
-    def get_main_task(self):
-        return self.order
-
-    def initial_prevision_date(self):
-        """returns the initial expected end of the milestone"""
-        return date.today()
-
-    def eta_date(self):
-        """returns expected date of completion based on what remains
-        to be done
-        """
-        return date.today()
-
-    def completion_date(self):
-        """returns date on which the subtask has been completed"""
-        return date.today()
-
-    def contractors(self):
-        """returns the list of persons supposed to work on this task"""
-        return []
-
-    def in_progress(self):
-        return self.state == u'in progress'
-
     def _compute_progress(self):
         self.progress_target = self.budget or 0
         self.progress_done = 0
@@ -101,10 +73,49 @@ class WorkOrder(ProgressMixIn, AnyEntity):
         else:
             self.debug('should have a order as parent')
 
+class WorkOrderIBreadCrumbsAdapter(IBreadCrumbsAdapter):
+    __select__ = is_instance('WorkOrder')
+
+    def parent_entity(self):
+        return self.entity.order
+
+
+class WorkOrderIMileStoneAdapter(IMileStoneAdapter):
+    __select__ = is_instance('WorkOrder')
+    parent_type = 'Order'
+
+    def get_main_task(self):
+        return self.entity.order
+
+    def initial_prevision_date(self):
+        """returns the initial expected end of the milestone"""
+        return date.today()
+
+    def eta_date(self):
+        """returns expected date of completion based on what remains
+        to be done
+        """
+        return date.today()
+
+    def completion_date(self):
+        """returns date on which the subtask has been completed"""
+        return date.today()
+
+    def contractors(self):
+        """returns the list of persons supposed to work on this task"""
+        return []
+
+    def in_progress(self):
+        return self.entity.cw_adapt_to('IWorkflowable').state == u'in progress'
+
     def progress_info(self):
-        return {'estimated': self.progress_target,
-                'estimatedcorrected': self.progress_target,
-                'done': self.progress_done,
-                'todo': self.progress_todo,
-                }
+        return {'estimated': self.entity.progress_target,
+                'estimatedcorrected': self.entity.progress_target,
+                'done': self.entity.progress_done,
+                'todo': self.entity.progress_todo,}
+
+# XXX IMileStone / IProgress inheritance stink
+class WorkOrderProgressAdapter(WorkOrderIMileStoneAdapter):
+    __regid__ = 'IProgress'
+    __select__ = is_instance('WorkOrder')
 
