@@ -6,13 +6,13 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.server.hook import Hook, match_rtype
 
 class WorkOrderProgressHook(Hook):
 
     __regid__ = 'workorder_progress_hook'
-    __select__ = Hook.__select__ & implements('WorkOrder')
+    __select__ = Hook.__select__ & is_instance('WorkOrder')
     events = ('before_add_entity', 'before_update_entity', )
 
     def __call__(self):
@@ -21,7 +21,7 @@ class WorkOrderProgressHook(Hook):
 class SplitIntoProgressHook1(Hook):
 
     __regid__ = 'split_into_progress_hook1'
-    __select__ = Hook.__select__ & implements('WorkOrder')
+    __select__ = Hook.__select__ & is_instance('WorkOrder')
     events = ('after_update_entity', )
 
     def __call__(self):
